@@ -13,9 +13,9 @@ use String::ShellQuote;
 use Exporter 'import';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-08-12'; # DATE
+our $DATE = '2022-10-15'; # DATE
 our $DIST = 'Perinci-CmdLine-POD'; # DIST
-our $VERSION = '0.034'; # VERSION
+our $VERSION = '0.036'; # VERSION
 
 our @EXPORT_OK = qw(gen_pod_for_pericmd_script);
 
@@ -70,8 +70,9 @@ sub _fmt_opt {
     } else {
         require Markdown::To::POD;
 
-        push @res, Markdown::To::POD::markdown_to_pod($ospec->{description}), "\n\n"
-            if $ospec->{description};
+        my $description = $ospec->{description} // '(No description)';
+        push @res, Markdown::To::POD::markdown_to_pod($description), "\n\n"
+            if $description;
     }
 
     if (defined $arg_spec->{pos}) {
@@ -532,7 +533,22 @@ sub gen_pod_for_pericmd_script {
     # section: SYNOPSIS
     {
         my @sectpod;
+
+        # 1. show usage that comes from common options
+
+        for my $opt (sort keys %{ $cli->{common_opts} || {} }) {
+            my $co_spec = $cli->{common_opts}{$opt};
+            if (defined $co_spec->{'usage.alt.fmt.pod'}) {
+                push @sectpod, "B<$program_name> ".$co_spec->{'usage.alt.fmt.pod'}."\n\n";
+            } elsif (defined $co_spec->{usage}) {
+                # text format, the next best thing
+                require String::PodQuote;
+                push @sectpod, "B<$program_name> ".String::PodQuote::pod_escape($co_spec->{usage})."\n\n";
+            }
+        }
+
         if ($cli->{subcommands}) {
+            # 2a. show per-subcommand usage lines, if there are subcommands
             if ($gen_scs) {
                 for my $sc_name (sort keys %clidocdata) {
                     next unless length $sc_name;
@@ -546,10 +562,13 @@ sub gen_pod_for_pericmd_script {
             }
             push @sectpod, "\n\n";
         } else {
+            # 2b. show main usage line
             my $usage = $clidocdata{''}->{'usage_line.alt.fmt.pod'};
             $usage =~ s/\[\[prog\]\]/$program_name/;
             push @sectpod, "$usage\n\n";
         }
+
+        # point to examples in Examples section, if any
         push @sectpod, "\n\nSee examples in the L</EXAMPLES> section.\n\n" if $has_examples;
 
         push @{ $resmeta->{'func.sections'} }, {name=>'SYNOPSIS', content=>join("", @sectpod), ignore=>1};
@@ -1084,7 +1103,7 @@ Perinci::CmdLine::POD - Generate POD for Perinci::CmdLine-based CLI script
 
 =head1 VERSION
 
-This document describes version 0.034 of Perinci::CmdLine::POD (from Perl distribution Perinci-CmdLine-POD), released on 2022-08-12.
+This document describes version 0.036 of Perinci::CmdLine::POD (from Perl distribution Perinci-CmdLine-POD), released on 2022-10-15.
 
 =head1 SYNOPSIS
 
